==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/en/gen70.h <==
/****************************************************************************

  module      : gen70.h

  -------------------------------------------------------------------------

  responsible : JoergM

  special area: init_shm
  description : Initialize Shared Section

  last changed: 1998-09-01  14:37
  see also    : example.html ...

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1998



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/


#ifndef GEN70_H
#define GEN70_H



/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "geo002.h"

/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/

externC int e70_init_kgs ( RTE_XPARAM_REC *XParam, key_t *pCommonKey );
externC int e70_get_shm_buffer2 ( void );
externC int e70_is_kgsshmid ( int shmid );

#endif  /* GEN70_H */

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/en/gen70.h <==
/****************************************************************************

  module      : gen70.h

  -------------------------------------------------------------------------

  responsible : JoergM

  special area: init_shm
  description : Initialize Shared Section

  last changed: 1998-09-01  14:37
  see also    : example.html ...

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1998



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/


#ifndef GEN70_H
#define GEN70_H



/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "geo002.h"

/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/

externC int e70_init_kgs ( RTE_XPARAM_REC *XParam );
externC int e70_get_shm_buffer2 ( void );
externC int e70_is_kgsshmid ( int shmid );

#endif  /* GEN70_H */
